var __defProp = Object.defineProperty;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};

// src/merge.ts
function deepMerge(target, ...sources) {
  const options = { clone: false };
  function isObject(item) {
    return item !== null && typeof item === "object" && !Array.isArray(item);
  }
  function mergeObject(targetObj, sourceObj) {
    const merged = options.clone ? __spreadValues({}, targetObj) : targetObj;
    for (const key of Object.keys(sourceObj)) {
      if (isObject(sourceObj[key])) {
        merged[key] = mergeNestedObjects(
          merged[key],
          sourceObj[key]
        );
      } else {
        merged[key] = sourceObj[key];
      }
    }
    return merged;
  }
  function mergeNestedObjects(targetObj, sourceObj) {
    if (!isObject(sourceObj))
      return sourceObj;
    for (const key of Object.keys(sourceObj)) {
      if (isObject(sourceObj[key])) {
        if (!targetObj[key]) {
          targetObj[key] = {};
        }
        targetObj[key] = mergeNestedObjects(
          targetObj[key],
          sourceObj[key]
        );
      } else {
        targetObj[key] = sourceObj[key];
      }
    }
    return targetObj;
  }
  let result = target;
  for (const source of sources) {
    if (source) {
      result = mergeObject(
        result,
        source
      );
    }
  }
  return result;
}
export {
  deepMerge
};
